@@ -21,6 +21,8 @@ pub(crate) enum MitPrepareCommitMessageError {
     ReadFromVcs(#[from] external::Error),
     #[error("{0}")]
     Utf8(#[from] std::string::FromUtf8Error),
+    #[error("failed to parse shell given {0}")]
+    BadShellCommand(#[from] shell_words::ParseError),
 }
 
 impl MitPrepareCommitMessageError {
